@@ -33,10 +33,16 @@ use crate::{
             },
         },
         guild::{
-            create_guild::CreateGuildError, create_guild_channel::CreateGuildChannelError,
+            create_guild::CreateGuildError,
+            create_guild_channel::CreateGuildChannelError,
+            sticker::{
+                CreateGuildSticker, DeleteGuildSticker, GetGuildSticker, GetGuildStickers,
+                StickerValidationError, UpdateGuildSticker,
+            },
             update_guild_channel_positions::Position,
         },
         prelude::*,
+        sticker::{GetNitroStickerPacks, GetSticker},
         GetUserApplicationInfo, Method, Request,
     },
     response::{future::InvalidToken, ResponseFuture},
@@ -63,7 +69,9 @@ use twilight_model::{
         command::{permissions::CommandPermissions, Command},
     },
     channel::{
-        message::allowed_mentions::AllowedMentions, thread::AutoArchiveDuration, ChannelType,
+        message::{allowed_mentions::AllowedMentions, sticker::StickerId},
+        thread::AutoArchiveDuration,
+        ChannelType,
     },
     guild::Permissions,
     id::{
@@ -1874,6 +1882,13 @@ impl Client {
     }
 
     /// Respond to an interaction, by ID and token.
+    ///
+    /// For variants of [`InteractionResponse`] that contain a [`CallbackData`],
+    /// there is an [associated builder] in the [`twilight-util`] crate.
+    ///
+    /// [`CallbackData`]: twilight_model::application::callback::CallbackData
+    /// [`twilight-util`]: https://docs.rs/twilight-util/latest/index.html
+    /// [associated builder]: https://docs.rs/twilight-util/latest/builder/struct.CallbackDataBuilder.html
     pub const fn interaction_callback<'a>(
         &'a self,
         interaction_id: InteractionId,
@@ -2206,11 +2221,17 @@ impl Client {
     /// This method is idempotent: it can be used on every start, without being
     /// ratelimited if there aren't changes to the commands.
     ///
+    /// The [`Command`] struct has an [associated builder] in the
+    /// [`twilight-util`] crate.
+    ///
     /// # Errors
     ///
     /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
     /// error type if an application ID has not been configured via
     /// [`Client::set_application_id`].
+    ///
+    /// [`twilight-util`]: https://docs.rs/twilight_util/index.html
+    /// [associated builder]: https://docs.rs/twilight-util/latest/builder/command/struct.CommandBuilder.html
     pub fn set_guild_commands<'a>(
         &'a self,
         guild_id: GuildId,
@@ -2371,11 +2392,17 @@ impl Client {
     /// This method is idempotent: it can be used on every start, without being
     /// ratelimited if there aren't changes to the commands.
     ///
+    /// The [`Command`] struct has an [associated builder] in the
+    /// [`twilight-util`] crate.
+    ///
     /// # Errors
     ///
     /// Returns an [`InteractionErrorType::ApplicationIdNotPresent`]
     /// error type if an application ID has not been configured via
     /// [`Client::set_application_id`].
+    ///
+    /// [`twilight-util`]: https://docs.rs/twilight-util/latest/index.html
+    /// [associated builder]: https://docs.rs/twilight-util/latest/builder/command/struct.CommandBuilder.html
     pub fn set_global_commands<'a>(
         &'a self,
         commands: &'a [Command],
@@ -2484,6 +2511,224 @@ impl Client {
         SetCommandPermissions::new(self, application_id, guild_id, permissions)
     }
 
+    /// Returns a single sticker by its ID.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use twilight_http::Client;
+    /// use twilight_model::channel::message::sticker::StickerId;
+    ///
+    /// # #[tokio::main]
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let client = Client::new("my token".to_owned());
+    ///
+    /// let id = StickerId(123);
+    /// let sticker = client.sticker(id).exec().await?.model().await?;
+    ///
+    /// println!("{:#?}", sticker);
+    /// # Ok(()) }
+    /// ```
+    pub const fn sticker(&self, sticker_id: StickerId) -> GetSticker<'_> {
+        GetSticker::new(self, sticker_id)
+    }
+
+    /// Returns a list of sticker packs available to Nitro subscribers.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use twilight_http::Client;
+    ///
+    /// # #[tokio::main]
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let client = Client::new("my token".to_owned());
+    ///
+    /// let packs = client.nitro_sticker_packs().exec().await?.model().await?;
+    ///
+    /// println!("{}", packs.sticker_packs.len());
+    /// # Ok(()) }
+    /// ```
+    pub const fn nitro_sticker_packs(&self) -> GetNitroStickerPacks<'_> {
+        GetNitroStickerPacks::new(self)
+    }
+
+    /// Returns a list of stickers in a guild.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use twilight_http::Client;
+    /// use twilight_model::{
+    ///     channel::message::sticker::StickerId,
+    ///     id::GuildId,
+    /// };
+    ///
+    /// # #[tokio::main]
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let client = Client::new("my token".to_owned());
+    ///
+    /// let guild_id = GuildId(1);
+    /// let stickers = client
+    ///     .guild_stickers(guild_id)
+    ///     .exec()
+    ///     .await?
+    ///     .models()
+    ///     .await?;
+    ///
+    /// println!("{}", stickers.len());
+    /// # Ok(()) }
+    /// ```
+    pub const fn guild_stickers(&self, guild_id: GuildId) -> GetGuildStickers<'_> {
+        GetGuildStickers::new(self, guild_id)
+    }
+
+    /// Returns a guild sticker by the guild's ID and the sticker's ID.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use twilight_http::Client;
+    /// use twilight_model::{
+    ///     channel::message::sticker::StickerId,
+    ///     id::GuildId,
+    /// };
+    ///
+    /// # #[tokio::main]
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let client = Client::new("my token".to_owned());
+    ///
+    /// let guild_id = GuildId(1);
+    /// let sticker_id = StickerId(2);
+    /// let sticker = client
+    ///     .guild_sticker(guild_id, sticker_id)
+    ///     .exec()
+    ///     .await?
+    ///     .model()
+    ///     .await?;
+    ///
+    /// println!("{:#?}", sticker);
+    /// # Ok(()) }
+    /// ```
+    pub const fn guild_sticker(
+        &self,
+        guild_id: GuildId,
+        sticker_id: StickerId,
+    ) -> GetGuildSticker<'_> {
+        GetGuildSticker::new(self, guild_id, sticker_id)
+    }
+
+    /// Creates a sticker in a guild, and returns the created sticker.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use twilight_http::Client;
+    /// use twilight_model::{
+    ///     channel::message::sticker::StickerId,
+    ///     id::GuildId,
+    /// };
+    ///
+    /// # #[tokio::main]
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let client = Client::new("my token".to_owned());
+    ///
+    /// let guild_id = GuildId(1);
+    /// let sticker = client
+    ///     .create_guild_sticker(
+    ///         guild_id,
+    ///         &"sticker name",
+    ///         &"sticker description",
+    ///         &"sticker,tags",
+    ///         &[23,23,23,23]
+    ///     )?
+    ///     .exec()
+    ///     .await?
+    ///     .model()
+    ///     .await?;
+    ///
+    /// println!("{:#?}", sticker);
+    /// # Ok(()) }
+    /// ```
+    pub fn create_guild_sticker<'a>(
+        &'a self,
+        guild_id: GuildId,
+        name: &'a str,
+        description: &'a str,
+        tags: &'a str,
+        file: &'a [u8],
+    ) -> Result<CreateGuildSticker<'_>, StickerValidationError> {
+        CreateGuildSticker::new(self, guild_id, name, description, tags, file)
+    }
+
+    /// Updates a sticker in a guild, and returns the updated sticker.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use twilight_http::Client;
+    /// use twilight_model::{
+    ///     channel::message::sticker::StickerId,
+    ///     id::GuildId,
+    /// };
+    ///
+    /// # #[tokio::main]
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let client = Client::new("my token".to_owned());
+    ///
+    /// let guild_id = GuildId(1);
+    /// let sticker_id = StickerId(2);
+    /// let sticker = client
+    ///     .update_guild_sticker(guild_id, sticker_id)
+    ///     .description("new description")?
+    ///     .exec()
+    ///     .await?
+    ///     .model()
+    ///     .await?;
+    ///
+    /// println!("{:#?}", sticker);
+    /// # Ok(()) }
+    /// ```
+    pub const fn update_guild_sticker(
+        &self,
+        guild_id: GuildId,
+        sticker_id: StickerId,
+    ) -> UpdateGuildSticker<'_> {
+        UpdateGuildSticker::new(self, guild_id, sticker_id)
+    }
+
+    /// Deletes a guild sticker by the ID of the guild and its ID.
+    ///
+    /// # Examples
+    ///
+    /// ```no_run
+    /// use twilight_http::Client;
+    /// use twilight_model::{
+    ///     channel::message::sticker::StickerId,
+    ///     id::GuildId,
+    /// };
+    ///
+    /// # #[tokio::main]
+    /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
+    /// let client = Client::new("my token".to_owned());
+    ///
+    /// let guild_id = GuildId(1);
+    /// let sticker_id = StickerId(2);
+    ///
+    /// client
+    ///     .delete_guild_sticker(guild_id, sticker_id)
+    ///     .exec()
+    ///     .await?;
+    /// # Ok(()) }
+    /// ```
+    pub const fn delete_guild_sticker(
+        &self,
+        guild_id: GuildId,
+        sticker_id: StickerId,
+    ) -> DeleteGuildSticker<'_> {
+        DeleteGuildSticker::new(self, guild_id, sticker_id)
+    }
+
     /// Execute a request, returning a future resolving to a [`Response`].
     ///
     /// # Errors
@@ -2568,6 +2813,12 @@ impl Client {
                 headers.insert(CONTENT_TYPE, content_type);
             }
 
+            #[cfg(feature = "decompression")]
+            headers.insert(
+                hyper::header::ACCEPT_ENCODING,
+                HeaderValue::from_static("br"),
+            );
+
             headers.insert(USER_AGENT, user_agent);
 
             if let Some(req_headers) = req_headers {
