@@ -84,6 +84,11 @@ pub enum Route<'a> {
         /// pruned.
         include_roles: &'a [RoleId],
     },
+    /// Route information to create a sticker in a guild.
+    CreateGuildSticker {
+        /// ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to create an invite to a channel.
     CreateInvite {
         /// The ID of the channel.
@@ -193,6 +198,13 @@ pub enum Route<'a> {
         /// The ID of the integration.
         integration_id: u64,
     },
+    /// Route information to delete a guild sticker.
+    DeleteGuildSticker {
+        /// ID of the guild.
+        guild_id: u64,
+        /// ID of the sticker.
+        sticker_id: u64,
+    },
     /// Route information to delete an invite.
     DeleteInvite {
         /// The unique invite code.
@@ -489,6 +501,18 @@ pub enum Route<'a> {
         /// The ID of the guild.
         guild_id: u64,
     },
+    /// Route information to get a guild's sticker.
+    GetGuildSticker {
+        /// ID of the guild.
+        guild_id: u64,
+        /// ID of the stickers.
+        sticker_id: u64,
+    },
+    /// Route information to get a guild's stickers.
+    GetGuildStickers {
+        /// ID of the guild.
+        guild_id: u64,
+    },
     /// Route information to get a guild's vanity URL.
     GetGuildVanityUrl {
         /// The ID of the guild.
@@ -568,6 +592,9 @@ pub enum Route<'a> {
         /// The maximum number of messages to get.
         limit: Option<u64>,
     },
+    /// Route information to get a list of sticker packs available to Nitro
+    /// subscribers.
+    GetNitroStickerPacks,
     /// Route information to get a channel's pins.
     GetPins {
         /// The ID of the channel.
@@ -619,6 +646,11 @@ pub enum Route<'a> {
         /// ID of the stage channel.
         channel_id: u64,
     },
+    /// Route information to get a sticker.
+    GetSticker {
+        /// ID of the sticker.
+        sticker_id: u64,
+    },
     /// Route information to get a template.
     GetTemplate {
         /// The template code.
@@ -829,6 +861,13 @@ pub enum Route<'a> {
         /// The ID of the integration.
         integration_id: u64,
     },
+    /// Route information to update a guild sticker.
+    UpdateGuildSticker {
+        /// ID of the guild.
+        guild_id: u64,
+        /// ID of the sticker.
+        sticker_id: u64,
+    },
     /// Route information to update a guild's welcome screen.
     UpdateGuildWelcomeScreen {
         /// ID of the guild.
@@ -981,6 +1020,7 @@ impl<'a> Route<'a> {
             | Self::DeleteGuild { .. }
             | Self::DeleteGuildCommand { .. }
             | Self::DeleteGuildIntegration { .. }
+            | Self::DeleteGuildSticker { .. }
             | Self::DeleteInteractionOriginal { .. }
             | Self::DeleteInvite { .. }
             | Self::DeleteMessageReactions { .. }
@@ -1028,6 +1068,8 @@ impl<'a> Route<'a> {
             | Self::GetGuildPreview { .. }
             | Self::GetGuildPruneCount { .. }
             | Self::GetGuildRoles { .. }
+            | Self::GetGuildSticker { .. }
+            | Self::GetGuildStickers { .. }
             | Self::GetGuildVanityUrl { .. }
             | Self::GetGuildVoiceRegions { .. }
             | Self::GetGuildWelcomeScreen { .. }
@@ -1040,12 +1082,14 @@ impl<'a> Route<'a> {
             | Self::GetMember { .. }
             | Self::GetMessage { .. }
             | Self::GetMessages { .. }
+            | Self::GetNitroStickerPacks { .. }
             | Self::GetPins { .. }
             | Self::GetJoinedPrivateArchivedThreads { .. }
             | Self::GetPrivateArchivedThreads { .. }
             | Self::GetPublicArchivedThreads { .. }
             | Self::GetReactionUsers { .. }
             | Self::GetStageInstance { .. }
+            | Self::GetSticker { .. }
             | Self::GetTemplate { .. }
             | Self::GetTemplates { .. }
             | Self::GetThreadMembers { .. }
@@ -1066,6 +1110,7 @@ impl<'a> Route<'a> {
             | Self::UpdateGuildCommand { .. }
             | Self::UpdateGuildWidget { .. }
             | Self::UpdateGuildIntegration { .. }
+            | Self::UpdateGuildSticker { .. }
             | Self::UpdateGuildWelcomeScreen { .. }
             | Self::UpdateInteractionOriginal { .. }
             | Self::UpdateMember { .. }
@@ -1086,6 +1131,7 @@ impl<'a> Route<'a> {
             | Self::CreateGuildFromTemplate { .. }
             | Self::CreateGuildIntegration { .. }
             | Self::CreateGuildPrune { .. }
+            | Self::CreateGuildSticker { .. }
             | Self::CreateInvite { .. }
             | Self::CreateMessage { .. }
             | Self::CreatePrivateChannel
@@ -1193,6 +1239,11 @@ impl<'a> Route<'a> {
             Self::CreateGuildPrune { guild_id, .. } | Self::GetGuildPruneCount { guild_id, .. } => {
                 Path::GuildsIdPrune(*guild_id)
             }
+            Self::CreateGuildSticker { guild_id, .. }
+            | Self::DeleteGuildSticker { guild_id, .. }
+            | Self::GetGuildSticker { guild_id, .. }
+            | Self::GetGuildStickers { guild_id, .. }
+            | Self::UpdateGuildSticker { guild_id, .. } => Path::GuildsIdStickers(*guild_id),
             Self::CreateInvite { channel_id } | Self::GetChannelInvites { channel_id } => {
                 Path::ChannelsIdInvites(*channel_id)
             }
@@ -1321,9 +1372,11 @@ impl<'a> Route<'a> {
             Self::GetMessage { channel_id, .. } => {
                 Path::ChannelsIdMessagesId(Method::Get, *channel_id)
             }
+            Self::GetNitroStickerPacks { .. } => Path::StickerPacks,
             Self::GetPins { channel_id } | Self::PinMessage { channel_id, .. } => {
                 Path::ChannelsIdPins(*channel_id)
             }
+            Self::GetSticker { .. } => Path::Stickers,
             Self::GetUserConnections => Path::UsersIdConnections,
             Self::GetVoiceRegions => Path::VoiceRegions,
             Self::InteractionCallback { interaction_id, .. } => {
